]> xenbits.xensource.com Git - qemu-xen-4.0-testing.git/commitdiff
Spelling fixes, by Stefan Weil.
authorths <ths@c046a42c-6fe2-441c-8c8c-71466251a162>
Sun, 3 Jun 2007 13:35:16 +0000 (13:35 +0000)
committerIan Jackson <Ian.Jackson@eu.citrix.com>
Fri, 23 May 2008 16:39:48 +0000 (17:39 +0100)
git-svn-id: svn://svn.savannah.nongnu.org/qemu/trunk@2927 c046a42c-6fe2-441c-8c8c-71466251a162

darwin-user/mmap.c
disas.c
exec.c
hw/cirrus_vga.c
hw/cuda.c
hw/ne2000.c
hw/scsi-disk.c
hw/vga.c
linux-user/elfload.c
sdl.c
target-i386/translate.c

index ada613d361041be96d2e64c9a94675e187b91d2c..b4055abe1bab377e914b3217e720aa769c58f5d0 100644 (file)
@@ -199,7 +199,7 @@ long target_mmap(unsigned long start, unsigned long len, int prot,
 
     if (!(flags & MAP_FIXED)) {
 #if defined(__alpha__) || defined(__sparc__) || defined(__x86_64__)
-        /* tell the kenel to search at the same place as i386 */
+        /* tell the kernel to search at the same place as i386 */
         if (host_start == 0) {
             host_start = last_start;
             last_start += HOST_PAGE_ALIGN(len);
diff --git a/disas.c b/disas.c
index 2979927984e1553a64a2303f5dc19f9b605330a4..162f52e0c381b5c728cb4ae550cd6990121f2d31 100644 (file)
--- a/disas.c
+++ b/disas.c
@@ -134,7 +134,7 @@ print_insn_thumb1(bfd_vma pc, disassemble_info *info)
 }
 #endif
 
-/* Disassemble this for me please... (debugging). 'flags' has teh following
+/* Disassemble this for me please... (debugging). 'flags' has the following
    values:
     i386 - nonzero means 16 bit code
     arm  - nonzero means thumb code 
diff --git a/exec.c b/exec.c
index ae2d825da34f44036eec24378c2e114ab9964996..9133b8be5bb8352b7544748927b2b68a42b1ec64 100644 (file)
--- a/exec.c
+++ b/exec.c
@@ -1152,7 +1152,7 @@ CPULogItem cpu_log_items[] = {
     { CPU_LOG_EXEC, "exec",
       "show trace before each executed TB (lots of logs)" },
     { CPU_LOG_TB_CPU, "cpu",
-      "show CPU state before bloc translation" },
+      "show CPU state before block translation" },
 #ifdef TARGET_I386
     { CPU_LOG_PCALL, "pcall",
       "show protected mode far calls/returns/exceptions" },
index f96ede93cb8b9ba54871e305cab58f289889b61b..1d192bd1d0c7de6b8432f9462cb9601fca0585ae 100644 (file)
@@ -2922,7 +2922,7 @@ static void vga_ioport_write(void *opaque, uint32_t addr, uint32_t val)
        case 0x09:
        case 0x0c:
        case 0x0d:
-       case 0x12:              /* veritcal display end */
+       case 0x12:              /* vertical display end */
            s->cr[s->cr_index] = val;
            break;
 
index f3c2b560105a34f96b84d71a01592fecdfceb6d6..14b69340a4273815282cf624ed46483e18ae1639 100644 (file)
--- a/hw/cuda.c
+++ b/hw/cuda.c
@@ -447,9 +447,9 @@ static void cuda_update(CUDAState *s)
             cuda_update_irq(s);
         } else {
             if (!(s->last_b & TIP)) {
-                /* handle end of host to cuda transfert */
+                /* handle end of host to cuda transfer */
                 packet_received = (s->data_out_index > 0);
-                /* always an IRQ at the end of transfert */
+                /* always an IRQ at the end of transfer */
                 s->ifr |= SR_INT;
                 cuda_update_irq(s);
             }
index a045a204307fd09731e136f111c9a0cf7dcdeb65..d27cd741a1e02f63652d91c886f8adda3b21b00b 100644 (file)
@@ -331,7 +331,7 @@ static void ne2000_ioport_write(void *opaque, uint32_t addr, uint32_t val)
         s->cmd = val;
         if (!(val & E8390_STOP)) { /* START bit makes no sense on RTL8029... */
             s->isr &= ~ENISR_RESET;
-            /* test specific case: zero length transfert */
+            /* test specific case: zero length transfer */
             if ((val & (E8390_RREAD | E8390_RWRITE)) &&
                 s->rcnt == 0) {
                 s->isr |= ENISR_RDC;
@@ -346,7 +346,7 @@ static void ne2000_ioport_write(void *opaque, uint32_t addr, uint32_t val)
                 if (index + s->tcnt <= NE2000_PMEM_END) {
                     qemu_send_packet(s->vc, s->mem + index, s->tcnt);
                 }
-                /* signal end of transfert */
+                /* signal end of transfer */
                 s->tsr = ENTSR_PTX;
                 s->isr |= ENISR_TX;
                 s->cmd &= ~E8390_TRANS; 
@@ -556,7 +556,7 @@ static inline void ne2000_dma_update(NE2000State *s, int len)
 
     if (s->rcnt <= len) {
         s->rcnt = 0;
-        /* signal end of transfert */
+        /* signal end of transfer */
         s->isr |= ENISR_RDC;
         ne2000_update_irq(s);
     } else {
index c6280fd5599c4103b33978a3af8fdd594345d3ac..b65bc5157b0c1f6e2eb0e15b180cd36de72bdc44 100644 (file)
@@ -488,7 +488,7 @@ int32_t scsi_send_command(SCSIDevice *s, uint32_t tag, uint8_t *buf, int lun)
         is_write = 1;
         break;
     case 0x35:
-        DPRINTF("Syncronise cache (sector %d, count %d)\n", lba, len);
+        DPRINTF("Synchronise cache (sector %d, count %d)\n", lba, len);
         bdrv_flush(s->bdrv);
         break;
     case 0x43:
index f5a9c6c14c17b9a13744b9c90b39a53602eccddc..2d2e6758eeca58e96e1011041d19a57a9aace73b 100644 (file)
diff --git a/sdl.c b/sdl.c
index 87ad3903c4d40990adfdf2f081adddde593ffafd..279b35e124193ead6e6035c49149df24fc878cbd 100644 (file)
--- a/sdl.c
+++ b/sdl.c
@@ -376,7 +376,8 @@ static void sdl_refresh(DisplayState *ds)
                         case SDLK_END: keysym = QEMU_KEY_END; break;
                         case SDLK_PAGEUP: keysym = QEMU_KEY_PAGEUP; break;
                         case SDLK_PAGEDOWN: keysym = QEMU_KEY_PAGEDOWN; break;
-                        case SDLK_BACKSPACE: keysym = QEMU_KEY_BACKSPACE; break;                        case SDLK_DELETE: keysym = QEMU_KEY_DELETE; break;
+                        case SDLK_BACKSPACE: keysym = QEMU_KEY_BACKSPACE; break;
+                        case SDLK_DELETE: keysym = QEMU_KEY_DELETE; break;
                         default: break;
                         }
                     }
index 735acb0e47d7c37afa22556cb649e85358ae82ad..e147704aad429d75162cd69a82ec58ea92cea792 100644 (file)
@@ -6430,7 +6430,7 @@ static void optimize_flags(uint16_t *opc_buf, int opc_buf_len)
 
     opc_ptr = opc_buf + opc_buf_len;
     /* live_flags contains the flags needed by the next instructions
-       in the code. At the end of the bloc, we consider that all the
+       in the code. At the end of the block, we consider that all the
        flags are live. */
     live_flags = CC_OSZAPC;
     while (opc_ptr > opc_buf) {
--- a/hw/vga.c
+++ b/hw/vga.c
@@ -346,7 +346,7 @@ static void vga_ioport_write(void *opaque, uint32_t addr, uint32_t val)
         case 0x09:
         case 0x0c:
         case 0x0d:
-        case 0x12: /* veritcal display end */
+        case 0x12: /* vertical display end */
             s->cr[s->cr_index] = val;
             break;
         default:
index c0ea5a01256116ba02b952ef69b97b4b0d07b086..f7b2fed64125ed73563fa56191babd8f05371dee 100644 (file)
@@ -729,7 +729,7 @@ static unsigned long load_elf_interp(struct elfhdr * interp_elf_ex,
 #endif
 
         if (interp_elf_ex->e_type == ET_DYN) {
/* in order to avoid harcoding the interpreter load
                address in qemu, we allocate a big enough memory zone */
             error = target_mmap(0, INTERP_MAP_SIZE,
                                 PROT_NONE, MAP_PRIVATE | MAP_ANON, 
@@ -1120,7 +1120,7 @@ int load_elf_binary(struct linux_binprm * bprm, struct target_pt_regs * regs,
                base, as well as whatever program they might try to exec.  This
                is because the brk will follow the loader, and is not movable.  */
             /* NOTE: for qemu, we do a big mmap to get enough space
-               without harcoding any address */
+               without hardcoding any address */
             error = target_mmap(0, ET_DYN_MAP_SIZE,
                                 PROT_NONE, MAP_PRIVATE | MAP_ANON, 
                                 -1, 0);
@@ -729,7 +729,7 @@ static unsigned long load_elf_interp(struct elfhdr * interp_elf_ex,
 
         if (interp_elf_ex->e_type == ET_DYN) {
-            /* in order to avoid harcoding the interpreter load
+            /* in order to avoid hardcoding the interpreter load
                address in qemu, we allocate a big enough memory zone */
             error = target_mmap(0, INTERP_MAP_SIZE,